pub struct IndexedRLE<T: Clone + Eq, S = usize> {
pub token: T,
pub start: S,
}Expand description
Represents an individual run of a specific token.
Individual runs are of indefinite length by themselves. The end of the run (and thus the length) is dictated by the start value of the next run in your sequence.
Type T is the token value that you’re encoding.
Type S is the sequence index type. The default of usize should work for most cases, but you
can save space if you know that your token sequences have a length that can be specified with a smaller
sized type.
Fields
token: Tstart: SImplementations
Sourceimpl<T: Clone + Eq, S> IndexedRLE<T, S>
impl<T: Clone + Eq, S> IndexedRLE<T, S>
pub fn new(token: T, start: S) -> Self
Sourcepub fn memory_size(&self) -> usize
pub fn memory_size(&self) -> usize
The amount of memory it takes to store this data.